@@ -9,40 +9,50 @@ class HauppaugePCTV1: public PIRKeysetMetaData
 {
 public:
   HauppaugePCTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class HauppaugePCTV1a: public HauppaugePCTV1
 {
 public:
   HauppaugePCTV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class HauppaugePCTV1b: public HauppaugePCTV1
 {
 public:
   HauppaugePCTV1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class HauppaugePCTV1c: public HauppaugePCTV1
 {
 public:
   HauppaugePCTV1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class HauppaugePCTV2: public PIRKeysetMetaData
 {
 public:
   HauppaugePCTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // HAUPPAUGE_H
