@@ -9,24 +9,30 @@ class RCATV1: public PIRKeysetMetaData
 {
 public:
   RCATV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCATV1a: public RCATV1
 {
 public:
   RCATV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCATV1b: public RCATV1
 {
 public:
   RCATV1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 /*
@@ -59,48 +65,60 @@ class RCAVCR1: public PIRKeysetMetaData
 {
 public:
   RCAVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCAVCR1a: public RCAVCR1
 {
 public:
   RCAVCR1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCADVD1: public PIRKeysetMetaData
 {
 public:
   RCADVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCADVD1a: public RCADVD1
 {
 public:
   RCADVD1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCASat1: public PIRKeysetMetaData
 {
 public:
   RCASat1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RCASat2: public PIRKeysetMetaData
 {
 public:
   RCASat2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // RCA_H
