@@ -5,6 +5,7 @@
 #include "mainwindow.h"
 
 #include <QSettings>
+#include <QComboBox>
 
 //#include <iostream>
 
@@ -23,6 +24,9 @@ PIRPreferencesForm::PIRPreferencesForm(
   setAttribute(Qt::WA_Maemo5StackedWindow);
   setWindowFlags(windowFlags() | Qt::Window);
 
+  setupMacroComboBox(ui->macroKbdComboBox);
+  setupMacroComboBox(ui->macroBtnComboBox);
+
   QSettings settings("pietrzak.org", "Pierogi");
 
   settings.beginGroup("Preferences");
@@ -61,6 +65,38 @@ PIRPreferencesForm::PIRPreferencesForm(
     }
   }
 
+  if (settings.contains("macroKbdFocus"))
+  {
+/*
+    int index = mainWindow->findMacroPack(
+      settings.value("macroKbdFocus").toString());
+*/
+    int index = settings.value("macroKbdFocus").toInt();
+
+    ui->macroKbdComboBox->setCurrentIndex(index);
+    mainWindow->setMacroKbdFocus(index);
+  }
+  else
+  {
+    mainWindow->setMacroKbdFocus(0);
+  }
+
+  if (settings.contains("macroBtnFocus"))
+  {
+/*
+    int index = mainWindow->findMacroPack(
+      settings.value("macroBtnFocus").toString());
+*/
+    int index = settings.value("macroBtnFocus").toInt();
+
+    ui->macroBtnComboBox->setCurrentIndex(index);
+    mainWindow->setMacroBtnFocus(index);
+  }
+  else
+  {
+    mainWindow->setMacroBtnFocus(0);
+  }
+
   settings.endGroup();
 }
 
@@ -152,3 +188,35 @@ void PIRPreferencesForm::on_altMainCheckBox_stateChanged(
 
   settings.endGroup();
 }
+
+
+void PIRPreferencesForm::on_macroKbdComboBox_activated(int index)
+{
+  QSettings settings("pietrzak.org", "Pierogi");
+  settings.beginGroup("Preferences");
+  settings.setValue("macroKbdFocus", index);
+  settings.endGroup();
+
+  mainWindow->setMacroKbdFocus(index);
+}
+
+
+void PIRPreferencesForm::on_macroBtnComboBox_activated(int index)
+{
+  QSettings settings("pietrzak.org", "Pierogi");
+  settings.beginGroup("Preferences");
+  settings.setValue("macroBtnFocus", index);
+  settings.endGroup();
+
+  mainWindow->setMacroBtnFocus(index);
+  mainWindow->updateUserButtons();
+}
+
+
+void PIRPreferencesForm::setupMacroComboBox(
+  QComboBox *cb)
+{
+  // Crappy hardcoded list.  Need to replace this...
+  cb->addItem("User Defined Macros");
+  cb->addItem("Reverse Multitap Keboard Macros");
+}
